netapp_ontap.resources.login_messages API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.login_messages`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

You can use this API to display and manage the login messages configuration. The GET request retrieves all of the login messages in the cluster. GET operations on /security/login/messages/{uuid} retrieve the login messages configuration by UUID. PATCH operations on /security/login/messages/{uuid} update the login messages configuration by UUID.

## Examples

### Retrieving all of the login messages in the cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(LoginMessages.get_collection(fields="*")))

Try it out

    [
        LoginMessages(
            {
                "message": "#### Welcome to Cluster X ####\n",
                "_links": {
                    "self": {
                        "href": "/api/security/login/messages/2581e5aa-9fe3-11e8-b309-005056bbef18"
                    }
                },
                "scope": "cluster",
                "show_cluster_message": True,
                "banner": "*** WARNING: DO NOT PROCEED IF YOU ARE NOT AUTHORIZED! ****\n",
                "uuid": "2581e5aa-9fe3-11e8-b309-005056bbef18",
            }
        ),
        LoginMessages(
            {
                "svm": {"uuid": "7b1b3715-9ffa-11e8-a5dd-005056bbef18", "name": "svm1"},
                "message": "#### Welcome to SVM1 ####\n",
                "_links": {
                    "self": {
                        "href": "/api/security/login/messages/7b1b3715-9ffa-11e8-a5dd-005056bbef18"
                    }
                },
                "scope": "svm",
                "show_cluster_message": True,
                "uuid": "7b1b3715-9ffa-11e8-a5dd-005056bbef18",
            }
        ),
        LoginMessages(
            {
                "svm": {"uuid": "8ddee11e-a58c-11e8-85e0-005056bbef18", "name": "svm3"},
                "_links": {
                    "self": {
                        "href": "/api/security/login/messages/8ddee11e-a58c-11e8-85e0-005056bbef18"
                    }
                },
                "scope": "svm",
                "banner": "*** WARNING: This system is for the use of authorized users only. ****\n",
                "uuid": "8ddee11e-a58c-11e8-85e0-005056bbef18",
            }
        ),
        LoginMessages(
            {
                "svm": {"uuid": "f7e41c99-9ffa-11e8-a5dd-005056bbef18", "name": "svm2"},
                "_links": {
                    "self": {
                        "href": "/api/security/login/messages/f7e41c99-9ffa-11e8-a5dd-005056bbef18"
                    }
                },
                "scope": "svm",
                "uuid": "f7e41c99-9ffa-11e8-a5dd-005056bbef18",
            }
        ),
    ]

### Retrieving the login messages configuration at the cluster scope

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(LoginMessages.get_collection(scope="cluster", fields="*")))

Try it out

    [
        LoginMessages(
            {
                "message": "#### Welcome to Cluster X ####\n",
                "_links": {
                    "self": {
                        "href": "/api/security/login/messages/2581e5aa-9fe3-11e8-b309-005056bbef18"
                    }
                },
                "scope": "cluster",
                "show_cluster_message": True,
                "banner": "*** WARNING: DO NOT PROCEED IF YOU ARE NOT AUTHORIZED! ****\n",
                "uuid": "2581e5aa-9fe3-11e8-b309-005056bbef18",
            }
        )
    ]

### Retrieving the login banner configured at the cluster scope

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(LoginMessages.get_collection(scope="cluster", fields="banner")))

Try it out

    [
        LoginMessages(
            {
                "_links": {
                    "self": {
                        "href": "/api/security/login/messages/2581e5aa-9fe3-11e8-b309-005056bbef18"
                    }
                },
                "scope": "cluster",
                "banner": "*** WARNING: DO NOT PROCEED IF YOU ARE NOT AUTHORIZED! ****\n",
                "uuid": "2581e5aa-9fe3-11e8-b309-005056bbef18",
            }
        )
    ]

### Retrieving the login messages configuration of a specific SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(LoginMessages.get_collection(fields="*", **{"svm.name": "svm1"})))

Try it out

    [
        LoginMessages(
            {
                "svm": {"uuid": "7b1b3715-9ffa-11e8-a5dd-005056bbef18", "name": "svm1"},
                "message": "#### Welcome to SVM1 ####\n",
                "_links": {
                    "self": {
                        "href": "/api/security/login/messages/7b1b3715-9ffa-11e8-a5dd-005056bbef18"
                    }
                },
                "scope": "svm",
                "show_cluster_message": True,
                "uuid": "7b1b3715-9ffa-11e8-a5dd-005056bbef18",
            }
        )
    ]

### Retrieving the login messages configuration by UUID, including all fields

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LoginMessages(uuid="7b1b3715-9ffa-11e8-a5dd-005056bbef18")
        resource.get(fields="*")
        print(resource)

Try it out

    LoginMessages(
        {
            "svm": {"uuid": "7b1b3715-9ffa-11e8-a5dd-005056bbef18", "name": "svm1"},
            "message": "#### Welcome to SVM1 ####\n",
            "_links": {
                "self": {
                    "href": "/api/security/login/messages/7b1b3715-9ffa-11e8-a5dd-005056bbef18"
                }
            },
            "scope": "svm",
            "show_cluster_message": True,
            "uuid": "7b1b3715-9ffa-11e8-a5dd-005056bbef18",
        }
    )

### Configuring the login banner in a cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LoginMessages()
        resource.banner = "You are entering secure area."
        resource.patch(hydrate=True, scope="cluster")

### Configuring the message of the day (MOTD) in a cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LoginMessages()
        resource.message = "Welcome to Cluster X"
        resource.show_cluster_message = True
        resource.patch(hydrate=True, scope="cluster")

### Clearing the login banner and message of the day (MOTD) in a cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LoginMessages()
        resource.banner = ""
        resource.message = ""
        resource.patch(hydrate=True, scope="cluster")

### Configuring the login messages for a specific SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LoginMessages()
        resource.banner = "AUTHORIZED ACCESS ONLY"
        resource.message = "WELCOME!"
        resource.patch(hydrate=True, **{"svm.name": "svm1"})

### Configuring the login messages by UUID

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LoginMessages(uuid="7b1b3715-9ffa-11e8-a5dd-005056bbef18")
        resource.banner = "AUTHORIZED ACCESS ONLY"
        resource.message = "WELCOME!"
        resource.patch()

### Clearing the login messages configuration by UUID

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import LoginMessages

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = LoginMessages(uuid="7b1b3715-9ffa-11e8-a5dd-005056bbef18")
        resource.banner = ""
        resource.message = ""
        resource.patch()

## Classes

`class LoginMessages (*args, **kwargs)`

  The login banner and message of the day (MOTD) configuration.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the login banner and messages of the day (MOTD) configured in the cluster and in specific SVMs.

    ### Learn more

    - `DOC /security/login/messages`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the login banner and messages of the day (MOTD) configured in the cluster and in specific SVMs.

    ### Learn more

    - `DOC /security/login/messages`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the login banner and messages of the day (MOTD) configured in the cluster and in specific SVMs.

    ### Learn more

    - `DOC /security/login/messages`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the login messages configuration. There are no required fields. An empty body makes no modifications.

    ### Learn more

    - `DOC /security/login/messages`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the login messages configuration by UUID.

    ### Learn more

    - `DOC /security/login/messages`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the login messages configuration. There are no required fields. An empty body makes no modifications.

    ### Learn more

    - `DOC /security/login/messages`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class LoginMessagesSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LoginMessages object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `banner GET POST PATCH`

    The login banner text. This message is displayed during SSH and console device login just before the password prompt displays. When configured, a cluster-level login banner is used for every incoming connection. Each data SVM can override the cluster-level banner to instead display when you log into the SVM. To restore the default setting for a data SVM, set the banner to an empty string. New lines are supplied as either LF or CRLF but are always returned as LF. Optional in the PATCH body.

  `links GET`

    The links field of the login_messages.

  `message GET POST PATCH`

    The message of the day (MOTD). This message appears just before the clustershell prompt after a successful login. When configured, the cluster message displays first. If you log in as a data SVM administrator, the SVM message is then printed. The cluster-level MOTD can be disabled for a given data SVM using the "show_cluster_message" property. New lines are supplied as either LF or CRLF but are always returned as LF. Optional in the PATCH body.

  `scope GET POST PATCH`

    The scope field of the login_messages.

  `show_cluster_message GET POST PATCH`

    Specifies whether to show a cluster-level message before the SVM message when logging in as an SVM administrator. This setting can only be modified by the cluster administrator. Optional in the PATCH body.

  `svm GET POST PATCH`

    The svm field of the login_messages.

  `uuid GET`

    The unique identifier (ID) of the login messages configuration.